﻿/*!
 *  Echo v1.4.0
 *  Lazy-loading with data-* attributes, offsets and throttle options
 *  Project: https://github.com/toddmotto/echo
 *  by Todd Motto: http://toddmotto.com
 *  Copyright. MIT licensed.
 */
window.Echo = (function(window, document, undefined) {

	'use strict';

	var store = [],
	offset,
	throttle,
	poll;

	var _inView = function(el) {
		var coords = el.getBoundingClientRect();
		return ((coords.top >= 0 && coords.left >= 0 && coords.top) <= (window.innerHeight || document.documentElement.clientHeight) + parseInt(offset));
	};

	var _pollImages = function() {
		for (var i = store.length; i--;) {
			var self = store[i];
			if (_inView(self)) {
				_imageCache(self);
				store.splice(i, 1);
			}
		}
	};
	
	var _imageCache = function(el){
		var imgUrl = el.getAttribute('data-echo');
		var path = imgUrl;
	    api.imageCache({
	        url: imgUrl,
	        policy:'cache_only',
	        thumbnail: false
	    },function(ret,err){
	        path = ret.url;
			if(el.style.background != null && el.style.background.indexOf("grey.gif")>-1){
				var str = 'url(' + path + ')  no-repeat center';
				el.style.background = str;
			}else if(el.style.backgroundImage != null && el.style.backgroundImage.indexOf("grey.gif")>-1){
				var str = 'url(' + path + ')';
				el.style.backgroundImage = str;
			}else if(el.src != null && el.src.indexOf("grey.gif")>-1){
				el.src = path;
			}
		});
	}

	var _throttle = function() {
		clearTimeout(poll);
		poll = setTimeout(_pollImages, throttle);
	};

	var init = function(obj) {
		var nodes = document.querySelectorAll('[data-echo]');
		var opts = obj || {};
		offset = opts.offset || 0;
		throttle = opts.throttle || 250;
		for (var i = 0; i < nodes.length; i++) {
			if(nodes[i].style.background != null && nodes[i].style.background.indexOf("grey.gif")>-1){
				store.push(nodes[i]);
			}
			else if(nodes[i].style.backgroundImage != null && nodes[i].style.backgroundImage.indexOf("grey.gif")>-1){
				store.push(nodes[i]);
			}
			else if(nodes[i].src != null && nodes[i].src.indexOf("grey.gif")>-1){
				store.push(nodes[i]);
			}
		}

		_throttle();

		if (document.addEventListener) {
			window.addEventListener('scroll', _throttle, false);
		} else {
			window.attachEvent('onscroll', _throttle);
		}
	};

	return {
		init: init,
		render: _throttle
	};

})(window, document);